@@ -49,6 +49,7 @@ void b_read(int sock, void* buf, size_t len)
   while(len>0)
   {
     size_t r=read(sock, buf, len);
+    if(r<1){return;}
     len-=r;
     buf+=r;
   }
@@ -226,6 +227,7 @@ void usage(const char* me)
   printf("Usage: %s [options] <channelname> <nickname> [channelpassword]\n"
          "Options include:\n"
          "-h, --help           Show this help text and exit\n"
+         "-v, --version        Show the program version and exit.\n"
          "-u, --user <user>    Username of tinychat account to use.\n"
          "-p, --pass <pass>    Password of tinychat account to use.\n"
          "-c, --color <value>  Color to use in chat.\n"
@@ -249,6 +251,7 @@ int main(int argc, char** argv)
   for(i=1; i<argc; ++i)
   {
     if(!strcmp(argv[i], "-h")||!strcmp(argv[i], "--help")){usage(argv[0]); return 0;}
+    if(!strcmp(argv[i], "-v")||!strcmp(argv[i], "--version")){printf("tc_client-"VERSION"\n"); return 0;}
     else if(!strcmp(argv[i], "-u")||!strcmp(argv[i], "--user"))
     {
       if(i+1==argc){continue;}
@@ -665,7 +668,7 @@ int main(int argc, char** argv)
     if(!rtmpres){printf("Server disconnected\n"); break;}
     if(rtmpres==2){continue;} // Not disconnected, but we didn't get a complete chunk yet either
     if(rtmp.type==RTMP_VIDEO || rtmp.type==RTMP_AUDIO){stream_handledata(&rtmp); continue;}
-    if(rtmp.type!=RTMP_AMF0){printf("Got RTMP type 0x%x\n", rtmp.type); continue;}
+    if(rtmp.type!=RTMP_AMF0){printf("Got RTMP type 0x%x\n", rtmp.type); fflush(stdout); continue;}
     struct amf* amfin=amf_parse(rtmp.buf, rtmp.length);
     if(amfin->itemcount>0 && amfin->items[0].type==AMF_STRING)
     {
