@@ -16,6 +16,12 @@
 */
 #include <gtk/gtk.h>
 
+struct channelopts
+{
+  int channel_id; // for editing an existing channel, otherwise pass -1
+  char save;
+};
+
 extern char autoscroll_before(GtkAdjustment* scroll);
 extern void autoscroll_after(GtkAdjustment* scroll);
 extern void settings_reset(GtkBuilder* gui);
@@ -24,3 +30,11 @@ extern void savesettings(GtkButton* button, GtkBuilder* gui);
 extern void toggle_soundcmd(GtkToggleButton* button, GtkBuilder* gui);
 extern void toggle_logging(GtkToggleButton* button, GtkBuilder* gui);
 extern void toggle_youtubecmd(GtkToggleButton* button, GtkBuilder* gui);
+extern void deletechannel(GtkButton* button, void* x);
+extern void channeldialog(GtkButton* button, struct channelopts* opts);
+extern void pm_open(const char* nick, char select);
+extern void pm_highlight(const char* nick);
+extern char pm_select(GtkNotebook* tabs, GtkWidget* tab, int num, void* x);
+extern void buffer_setup_colors(GtkTextBuffer* buffer);
+
+extern GtkBuilder* gui;
