@@ -193,6 +193,7 @@ int main(int argc, char** argv)
   char daemon=0;
   char* logfile=0;
   char verbose=0;
+  char disablelists=0;
   unsigned int i;
   for(i=1; i<argc; ++i)
   {
@@ -223,12 +224,22 @@ int main(int argc, char** argv)
       argv[argc]=0;
       --i;
     }
+    else if(!strcmp(argv[i], "--disable-lists"))
+    {
+      disablelists=1;
+      // Remove non-tc_client argument
+      --argc;
+      memmove(&argv[i], &argv[i+1], sizeof(char*)*(argc-i));
+      argv[argc]=0;
+      --i;
+    }
     else if(!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help"))
     {
       printf("Additional options for modbot:\n"
              "-d/--daemon     = daemonize after startup\n"
              "-l/--log <file> = log output into <file>\n"
              "-v/--verbose    = print/log all incoming messages\n"
+             "--disable-lists = disable playlists\n"
              "\n");
       execvp(strncmp(argv[0], "./", 2)?"tc_client":"./tc_client", argv);
       return 1;
@@ -343,6 +354,12 @@ int main(int argc, char** argv)
         }
         if(!strncmp(msg, "!request ", 9))
         {
+          if(disablelists)
+          {
+            char* x;
+            if((x=strstr(&msg[9], "&list="))){x[0]=0;}
+            if((x=strstr(&msg[9], "?list="))){x[1]='_';}
+          }
           char title[256];
           char vid[1024];
           char viderr[1024];
@@ -407,6 +424,12 @@ int main(int argc, char** argv)
             --i;
             if(!strcmp(queue.items[i].requester, nick))
             {
+              say(0, "/priv %s Removing '%s' from queue\n", nick, queue.items[i].title);
+              if(list_contains(&mods, nick) && goodvids.itemcount && !strcmp(goodvids.items[goodvids.itemcount-1], queue.items[i].video))
+              {
+                list_del(&goodvids, queue.items[i].video); // Un-approve the video since it was probably a bad search result and auto-approved because the requester is a mod
+                list_save(&goodvids, "goodvids.txt");
+              }
               queue_del(&queue, queue.items[i].video);
               if(!playing && i==0){playnext(0);}
               i=1; // distinguish from just having reached the front of the queue
@@ -427,6 +450,12 @@ int main(int argc, char** argv)
           {
             if(!strcmp(queue.items[i].requester, nick) && !strcmp(queue.items[i].video, vid))
             {
+              say(0, "/priv %s Removing '%s' from queue\n", nick, queue.items[i].title);
+              if(list_contains(&mods, nick) && goodvids.itemcount && !strcmp(goodvids.items[goodvids.itemcount-1], queue.items[i].video))
+              {
+                list_del(&goodvids, queue.items[i].video); // Un-approve the video since it was probably a bad search result and auto-approved because the requester is a mod
+                list_save(&goodvids, "goodvids.txt");
+              }
               queue_del(&queue, queue.items[i].video);
               break;
             }
@@ -626,12 +655,19 @@ int main(int argc, char** argv)
           {
             unsigned int num=((msg[5]&&msg[6])?strtoul(&msg[6], 0, 0):1);
             if(num<1){say(pm, "The given value evaluates to 0, please specify the number of videos you would like to skip (or if you do not specify it will default to 1)\n"); continue;}
-            if(playing){free(playing); playing=0; --num; say(0, "/mbc youTube\n");}
+            if(playing){--num; say(0, "/mbc youTube\n");}
+            say(0, "/priv %s Skipping %u videos. Note that these videos are not marked as bad (!badvid). Videos: %s", nick, num+(!!playing), playing?playing:"");
+            char first=!playing;
             while(num>0&&queue.itemcount>0)
             {
+              say(0, "%s%s", first?"":", ", queue.items[0].video);
+              first=0;
               queue_del(&queue, queue.items[0].video);
               --num;
             }
+            say(0, "\n");
+            free(playing);
+            playing=0;
             playnext(0);
           }
           else if(!strncmp(msg, "/mbs youTube ", 13))
